import java.sql.*;
import java.text.*;

/*
 This class illustrates how to use user-defined functions
 at the data processing.
*/

public class UFTest {
  static SimpleDateFormat day_format = new SimpleDateFormat("dd");
  static SimpleDateFormat month_format = new SimpleDateFormat("MM");
  static SimpleDateFormat year_format = new SimpleDateFormat("yyyy");

  // user-defined SQL functions
  public static Integer day_func(java.util.Date date){
    // process the null value
    if (date == null) return null;
    // return a function result with the java.lang.Integer type
    return new Integer(day_format.format(date));
  }

  public static Integer month_func(java.util.Date date){
    // process the null value
    if (date == null) return null;
    // return a function result with the java.lang.Integer type
    return new Integer(month_format.format(date));
  }

  public static Integer year_func(java.util.Date date){
    // process the null value
    if (date == null) return null;
    // return a function result with the java.lang.Integer type
    return new Integer(year_format.format(date));
  }
  // end of user-defined SQL functions

  public static void main(String[] args)
  {
    try
    {
      // load the driver into memory
      Class.forName("jstels.jdbc.engine.EngineDriver");

      // register the user-defined functions in the driver
      jstels.jdbc.engine.EngineDriver.registerFunction("day",
          "UFTest.day_func");
      jstels.jdbc.engine.EngineDriver.registerFunction("month",
          "UFTest.month_func");
      jstels.jdbc.engine.EngineDriver.registerFunction("year",
          "UFTest.year_func");

      // create a connection
      Connection conn = DriverManager.getConnection("jdbc:jstels:engine");

      // create a Statement object to execute the query with
      Statement stmt = conn.createStatement();

      // create a data table
      stmt.execute("CREATE TABLE employee(id int, age int, name string, hiredate datetime)");

      // insert the records into the table
      stmt.execute("INSERT INTO employee(id, age, name, hiredate) VALUES(1,32,'Bill Adams',to_date('21-05-1992','dd-MM-yyyy'))");
      stmt.execute("INSERT INTO employee(id, age, name, hiredate) VALUES(1,25,'Mary Jones',to_date('12-06-1995','dd-MM-yyyy'))");
      stmt.execute("INSERT INTO employee(id, age, name, hiredate) VALUES(1,35,'Sue Smith',to_date('03-04-1992','dd-MM-yyyy'))");
      stmt.execute("INSERT INTO employee(id, age, name, hiredate) VALUES(1,24,'Dan Roberts',to_date('20-10-1999','dd-MM-yyyy'))");
      stmt.execute("INSERT INTO employee(id, age, name, hiredate) VALUES(1,29,'Paul Cruz',to_date('08-12-2000','dd-MM-yyyy'))");

      // execute a query with the user-defined functions
      ResultSet rs = stmt.executeQuery("SELECT name, day(hiredate) as \"Day\", month(hiredate) as \"Month\", year(hiredate) as \"Year\" FROM employee");

      // read the data and put it to the console
      for (int j = 1; j <= rs.getMetaData().getColumnCount(); j++) {
        System.out.print(rs.getMetaData().getColumnName(j) + "\t");
      }
      System.out.println();

      while (rs.next())
      {
            for(int j=1; j <= rs.getMetaData().getColumnCount(); j++){
                   System.out.print(rs.getObject(j)+ "\t");
            }
            System.out.println();
      }

      // close the objects
      rs.close();
      stmt.close();
      conn.close();
    }
    catch(Exception e)
    {
      e.printStackTrace();
    }
  }

}